@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2003 Oliver Heidelbach
+@c Copyright (C) 1993/2005 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -36,6 +36,9 @@ Cell Arrival (ATM)
 @item CA
 Certification Authority (cryptography, PKI)
 
+@item CA
+Channel Adapter (Infiniband)
+
 @item CA
 Computer Animation
 
@@ -54,6 +57,9 @@ Carrier Access Billing System
 @item CABS
 Computer Aided Business Simulation
 
+@item CAC
+Cantilver Array Chip (IBM, HDD, MEMS)
+
 @item CAC
 Channel Access Code (Bluetooth)
 
@@ -135,9 +141,15 @@ Common Access Method (SCSI)
 @item CAM
 Computer Aided Manufacturing
 
+@item CAM
+Content Addressable Memory (ethernet, Switch)
+
 @item CAMAC
 Computer Automated Measurement And Control
 
+@item CAMEL
+Customized Applications for Mobile network Enhanced Logic (UMTS)
+
 @item CAMM
 Computer Assisted Material Management
 
@@ -147,6 +159,9 @@ Complete Area Networks (SNI)
 @item CAN
 Controller Area Network [bus] (CAN)
 
+@item CAO
+Client Activated Object (SAO)
+
 @item CAO
 Computer Aided Office
 
@@ -180,6 +195,9 @@ Cryptography Application Programming Interface (cryptography, API)
 @item CAPP
 Computer Aided Process Planning
 
+@item CAPPEAL
+Controlled Access Protection Profile / Evaluation Assurance Level, "CAPP/EAL"
+
 @item CAPSL
 CAnnon Printing System Language (Canon), "CaPSL"
 
@@ -216,6 +234,12 @@ Computer Assistance Resource Exchange
 @item CARLOS
 Computer Aided Real Language Orthographic System
 
+@item CARP
+Common Address Redundancy Protocol (BSD)
+
+@item CAS
+Code Access Security (VSTO, .NET, MS)
+
 @item CAS
 Column Address Strobe (IC, DRAM)
 
@@ -231,6 +255,9 @@ Computer Algebra System
 @item CAS
 Computerized Autodial System
 
+@item CAS
+Content Addressed Storage (EMC)
+
 @item CASE
 Common Application Service Element (ISO, OSI)
 
@@ -270,6 +297,9 @@ Computer-Assisted Tactical Information System (mil., USA)
 @item CATNIP
 Common ArchiTecture for Next generation Internet Protocol (IPNG, RFC 1707)
 
+@item CATOSL
+Computer Associates - Trusted Open Source License (CA), "CA-TOSL"
+
 @item CATS
 CodeWarrior Analysis Tools
 
@@ -322,7 +352,7 @@ Computer & Business Equipment Manufacturers Association (org.)
 Code Behind Form (MS, Access, DB)
 
 @item CBGA
-Ceramic Ball and Grid Array (IC)
+Ceramic Ball and Grid Array (IC, CPU)
 
 @item CBIOS
 Compatibility Basic Input Output System (IBM, BIOS)
@@ -369,6 +399,9 @@ Cross Connector
 @item CCAF
 Call Control Agent Function (IN)
 
+@item CCC
+Cablelabs Client Configuration (DHCP)
+
 @item CCC
 Chaos Computer Club (org.)
 
@@ -433,7 +466,7 @@ Comite Consultatif International Telegraphique et Telephonique (org., ITU, prede
 Cerberus Central Limited (manufacturer)
 
 @item CCM
-Change Configuration Management
+Change and Configuration Management
 
 @item CCM
 CORBA Component Model (CORBA)
@@ -462,6 +495,9 @@ Communications Control Program (OS, IBM)
 @item CCP
 Compact Communication Products (TPS)
 
+@item CCPP
+Composite Capability / Prefrence Profiles (W3C, RDF), "CC/PP"
+
 @item CCR
 Commitment, Concurrency and Recovery (OSI)
 
@@ -508,7 +544,7 @@ Cooperative Computing System Program (HP)
 China Coast Time [+0800] (TZ)
 
 @item CCTA
-Central Computer and Telecommunications Agency (org., UK)
+Central Computer and Telecommunications Agency (org., UK, predecessor, OGC)
 
 @item CCTLD
 Country Code Top Level DOMAIN (Internet, ICANN), "ccTLD"
@@ -642,6 +678,9 @@ Cellular Digital Packet Data
 @item CDPD
 Cellular Digital Packet Data (mobile-systems)
 
+@item CDPN
+Context Dependent Path Names (CDSL, NFS, GFS)
+
 @item CDR
 Compact Disk - Recordable (CD), "CD-R" 
 
@@ -678,6 +717,9 @@ Common Data Securuty Architecture (HP, cryptography)
 @item CDSG
 Cultural Diversity Steering Group (ISSS)
 
+@item CDSL
+Context Dependent Symbolic Links (CDPN, NFS, GFS)
+
 @item CDSS
 Creative Decision Stimulation Systems (AI, DSS)
 
@@ -687,6 +729,9 @@ Cell Delay Tolerance (ATN)
 @item CDT
 Central Daylight Time [-0500] (TZ, CST, USA)
 
+@item CDT
+Compressed DOMAIN Transcoder (DVD)
+
 @item CDTV
 Commodore Dynamic Total Vision (Commodore)
 
@@ -717,6 +762,9 @@ Cisco Educational ARCHive (Cisco, WWW)
 @item CEBIT
 welt CEntrum Buero Information Telekommunikation (fair), "CeBIT"
 
+@item CEC
+Consumer Electronics Control [protocol]
+
 @item CECI
 CICS Enhanced Command Interpreter (IBM, CICS)
 
@@ -823,7 +871,7 @@ Carry Flag (assembler)
 Compact Flash [card]
 
 @item CF
-Compact Framework (MS, .NET)
+Compact Framework (MS, .NET, PocketPC)
 
 @item CFA
 Center for Architecture (org., JIEO, DISA)
@@ -870,6 +918,9 @@ Cold Fusion Markup Language
 @item CFP
 Call For Papers
 
+@item CFP
+Computers, Freedom & Privacy [conference]
+
 @item CFP
 Contention Free Period (PCF, MAC)
 
@@ -918,6 +969,9 @@ Copy Generation Management System (CD)
 @item CGRM
 Computer Graphics Reference Model (ISO, IEC, ISO/IEC 11072)
 
+@item CGS
+Continuous Grain Silicon [technology] (Sharp, LCD)
+
 @item CGVDI
 Computer Graphic Virtual Device Interface, "CG-VDI"
 
@@ -943,7 +997,7 @@ CCITT HIgh Level programming Language (CCITT)
 Common Hardware Reference Platform (AIM)
 
 @item CHS
-Cylinder Head Sectors
+Cylinder Head Sectors (HDD, BIOS)
 
 @item CHSM
 C Hardware Specific Module (NEST, MLID, Novell)
@@ -972,6 +1026,9 @@ CAN In Automation (org., CAN), "CiA"
 @item CIAC
 Computer Incident Advisory Capability (org., LLNL, Internet)
 
+@item CIB
+Collective Intelligent Brick (IBM, HDD)
+
 @item CIB
 Computer Integrated Business
 
@@ -1027,7 +1084,7 @@ Component Integration LABoratorieS (org.,, OpenDoc, Apple, IBM, Adobe, ...), CIL
 Cisco Interactive Mentor (Cisco)
 
 @item CIM
-Common Information Model (DMTF, XML, DMI, SAN)
+Common Information Model (DMTF, XML, DMI, SAN, WBEM)
 
 @item CIM
 Computer Integrated Manufacturing
@@ -1059,6 +1116,9 @@ Computer Integrated Processing
 @item CIP
 Computer-Investitions-Programm
 
+@item CIPA
+Camera & Imaging Products Association (org.)
+
 @item CIPA
 Children's Internet Protection Act (Internet, USA, COPA)
 
@@ -1086,6 +1146,9 @@ Compuserve Information Systems (network)
 @item CIS
 Contact Image Sensor
 
+@item CISA
+Certified Information Systems Auditor (ISACA)
+
 @item CISC
 Complex Instruction Set Computer (CPU)
 
@@ -1095,12 +1158,21 @@ Computer and Information Science Directorate (org., NSF)
 @item CISKA
 [3D] Campus-InformationsSystem KArlsruhe (Uni Karlsruhe, Germany, VRML)
 
+@item CISM
+Certified Information Security Manager (ISACA)
+
+@item CISO
+Certified Information Security Officer (ISTA)
+
 @item CISPR
 Comite International Special des Perturbations Radioelectriques (org.)
 
 @item CISS
 Center for Information Systems Security (org., JIEO, DISA, mil., USA)
 
+@item CISSP
+Certified Information Systems Security Professional (ISC2)
+
 @item CIT
 Computer Integrated Telephony
 
@@ -1287,6 +1359,9 @@ Connection Manager Interface (IBM, SNA)
 @item CMIA
 China Medical Informatics Association (org., China)
 
+@item CMIIW
+Correct Me If I'm Wrong (slang, Usenet, IRC)
+
 @item CMIP
 Common Management Information Protocol (OSI, ISO, DP 9506, X.700)
 
@@ -1404,6 +1479,9 @@ Caller Number Delivery (MODEM)
 @item CNE
 Certified Netware Engineer (Novell, Netware)
 
+@item CNE
+Corporate Network Edition (eBlaster)
+
 @item CNEPA
 Certified Netware Engineers Professional Association (org., Netware)
 
@@ -1554,9 +1632,15 @@ COMmon Algorithmic Language
 @item COMDEX
 COMputer Dealer's EXposition (fair)
 
+@item COMIC
+COnversational Multimodal Interaction with Computers [project] (Europe)
+
 @item COMPARTS
 COMputergestuetztes PARtner-TeilebestandsSystem (MBAG)
 
+@item COMPTIA
+COMPuting Technology Industry Association (org.)
+
 @item COMTECH
 COMputer TECHnologies (fair)
 
@@ -1590,6 +1674,9 @@ Child Online Protection Act (Internet, USA, CIPA)
 @item COPS
 Common Open Policy Service protocol (RFC 2748)
 
+@item COPS
+Computer Oracle and Password System (Unix)
+
 @item COPSPR
 Common Open Policy Service for Policy Provisioning (COPS, RFC 3084), "COPS-PR"
 
@@ -1674,6 +1761,9 @@ Control Program (IBM, OS, VM/ESA, VM)
 @item CP
 Coordination Point (ISO 9646-3, TTCN)
 
+@item CPA
+Collaboration Partner Agreement (CPPA, ebXML)
+
 @item CPA
 Collaboration Protocol Agreements (ebXML)
 
@@ -1692,6 +1782,9 @@ Common Part Convergence Sublayer (ATM)
 @item CPDP
 Cellular Digital Packet Data
 
+@item CPE
+Continuing Professional Education
+
 @item CPE
 Customer Premises Equipment
 
@@ -1699,7 +1792,7 @@ Customer Premises Equipment
 Control Program Facility (OS, IBM, S/38)
 
 @item CPGA
-Ceramic Pin Grid Array (CPU)
+Ceramic Pin Grid Array (IC, CPU)
 
 @item CPH
 Cost Per Hour
@@ -1728,6 +1821,12 @@ Common Programming Interface Resource Recovery (IBM, SAA)
 @item CPL
 Combined Programming Language (DEC, PL/1)
 
+@item CPL
+Common Public License (IBM, IPL)
+
+@item CPL
+Control Panel Applet (MS, Windows, XP)
+
 @item CPL
 Conversational Programming Language (DEC)
 
@@ -1767,9 +1866,15 @@ Control Program / ??? (CP/NET, CP/M, OS), "CP/NOS"
 @item CPODA
 Contention Priority Orientated Demand Assignment (MAC, PODA)
 
+@item CPP
+Collaboration Partner Profile (CPPA, ebXML)
+
 @item CPP
 Collaboration Protocol Profiles (ebXML)
 
+@item CPPA
+Collaboration Partner Profile and Agreement (ebXML, XML)
+
 @item CPPS
 Card / Paper tape Programming System (OS, IBM)
 
@@ -1791,6 +1896,9 @@ Central Processing Unit
 @item CPUID
 Central Processing Unit IDentifier (CPU)
 
+@item CPW
+Cross-Platform Windowing [library] (OpenGL)
+
 @item CR
 Carriage Return (ASCII)
 
@@ -1846,13 +1954,13 @@ Complex-Reduced Instruction Set Computer
 Complex-Reduced Instruction Set Processor
 
 @item CRISP
-Cross Registry Internet Service Protocol (Internet)
+Cross Registry Internet Service Protocol (Internet, RFC 3707)
 
 @item CRJE
 Conversational Remote Job Entry (RJE)
 
 @item CRL
-Certificate Revocation List
+Certificate Revocation List (cryptography)
 
 @item CRL
 Compile-time Reconfigurable Logic (RL)
@@ -2028,6 +2136,9 @@ Computer SoLutions [software gmbh] (Haendler)
 @item CSLIP
 Compressed [headers] Serial Line Internet Protocol (SLIP, IP)
 
+@item CSM
+Cluster System Management (IBM)
+
 @item CSMA
 Carrier Sense Multiple Access
 
@@ -2076,6 +2187,9 @@ Cell misSequenced Ratio (ATM)
 @item CSR
 Cell Switch Router (Toshiba)
 
+@item CSR
+Certificate Signing Request (SSL)
+
 @item CSRAM
 Clock Synchronous Random Access Memory (RAM, IC)
 
@@ -2121,6 +2235,9 @@ Channel Service Unit (ATM)
 @item CSUNET
 California State University NETwork (network, USA)
 
+@item CSV
+Client SMTP Validation (SMTP, SPAM)
+
 @item CSV
 Comma Separated Values
 
@@ -2133,6 +2250,9 @@ Chipcard Terminal (ICC, CT)
 @item CT
 Chips & Technologies (manufacturer), "C&T"
 
+@item CT
+Clackamas Technology (Intel, Pentium, CPU)
+
 @item CTAN
 Comprehensive Tex Archive Network (TeX, FTP)
 
@@ -2160,6 +2280,9 @@ Compliance Test and Evaluation, "CT & E"
 @item CTEA
 Copyright Term Extension Act (USA,  DRM)
 
+@item CTEC
+Certified Technical Education Center (MS)
+
 @item CTERM
 Command TERMinal (DEC)
 
@@ -2202,6 +2325,9 @@ Compatibility Test Suite (Sun, J2EE)
 @item CTS
 Conformance Testing Service (OSTC)
 
+@item CTS
+Cut-Through-Switch (FC, PMC-Sierra)
+
 @item CTSM
 C Topology Specific Module (NEST, MLID, Novell)
 
@@ -2244,9 +2370,15 @@ Character User Interface (UI)
 @item CUI
 Common User Interface (AMS, UI)
 
+@item CUL
+Computer Und Lernen (org.)
+
 @item CUP
 Competitive UPgrade (MS)
 
+@item CUPS
+Common Unix Printing System (Unix, printing)
+
 @item CUSI
 Configurable Unified Search Interface (WWW)
 
@@ -2263,7 +2395,7 @@ ComputerUnterstuetzte Unterweisung
 Chemical Vapor Deposition
 
 @item CVE
-Common Vulnerabilities and Exposures
+Common Vulnerabilities and Exposures (org.)
 
 @item CVF
 Compressed Volume File (DOS)
