@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2003 Oliver Heidelbach
+@c Copyright (C) 1993/2005 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -51,6 +51,9 @@ Field Application Engineer
 @item FAG
 FernmeldeAnlagenGesetz telecommunication, Germany
 
+@item FAI
+Fully Automatic Installation
+
 @item FAID
 Flash Authority Identification Data (EEPROM)
 
@@ -111,6 +114,9 @@ Forschungsinstitut fuer Angewandte Software-Technologie [e.v.] (org.)
 @item FAT
 File Allocation Table (DOS)
 
+@item FATA
+Fibre-Attached Technology Adapted (HP, SATA, HDD)
+
 @item FAU
 Flow Admission Update [message] (LFAP)
 
@@ -129,6 +135,9 @@ Fiber optic Backbone
 @item FBAS
 FarbBild-AustastSystem / Farb-Bild-Austast-Synchron-signal (video)
 
+@item FBDIMM
+Fully Buffered Dual Inline Memory Module (DIMM, IC, RAM), "FB-DIMM"
+
 @item FBL
 Frame Burst error Length (CD)
 
@@ -148,7 +157,7 @@ Federal Criteria [for information technology security] (NIST, USA)
 Feedback Control
 
 @item FC
-Fibre Channel
+Fibre Channel (FC)
 
 @item FC
 Frame Control (FDDI, Token Ring)
@@ -186,6 +195,9 @@ Fundacao para a Computacao Cientifica Nacional (org., Portugal)
 @item FCD
 Floating Car Data
 
+@item FCDAE
+Fibre Channel Disk Array Enclosure (FC), "FC-DAE"
+
 @item FCFS
 First Come, First Served
 
@@ -220,7 +232,7 @@ Flow Control Operator Bits (DLSW, BIT)
 [SCSI-3] Fibre Channel Protocol (SAM)
 
 @item FCPGA
-Flip Chip Pin Grid Array (CPU), "FC-PGA"
+Flip Chip Pin Grid Array (IC, CPU), "FC-PGA"
 
 @item FCPH
 Fibre Channel PHysical and signaling interface (SAM), "FC-PH"
@@ -411,6 +423,9 @@ Fixed Global Regular Expression Print (Unix, GREP)
 @item FHGS
 FreeHand Graphics Studio (Macromedia, DTP)
 
+@item FHS
+File system Hierarchy Standard (Linux, LSB)
+
 @item FHSS
 Frequency Hopping Spread Spectrum (WLAN)
 
@@ -459,6 +474,9 @@ First In Last Out
 @item FIMAS
 Financial Institution Message Authentication Standard (banking, ANSI)
 
+@item FINTS
+FINancial Transaction Services (banking, HBCI), "FinTS"
+
 @item FIOC
 Frame Input/Output Controller
 
@@ -543,6 +561,9 @@ Full Level Algol Checkout Compiler
 @item FLAME
 FLexible API for Module-based Environments (RL, API)
 
+@item FLASK
+FLux Advanced Security Kernel (DTOS)
+
 @item FLC
 Ferroelectric Liquid Crystal
 
@@ -600,6 +621,9 @@ Fiber Optic
 @item FOA
 Fiber Optic Association (org.)
 
+@item FOAF
+Friend Of A Friend [vocabulary] (RDF)
+
 @item FOC
 Fiber Optic Cable / Communications
 
@@ -630,12 +654,18 @@ Free OnLine Dictionary Of Computing (WWW, UK)
 @item FOLED
 Flexible Organic Light Emitting Display (OLED)
 
+@item FOMA
+Freedom Of Multimedia Access (Japan, mobile-systems)
+
 @item FOMAU
 Fiber Optic MAU (ethernet, MAU)
 
 @item FON
 Fiber Optics Network
 
+@item FOO
+Friends Of O'reilly [meeting]
+
 @item FOOBAR
 FTP Operation Over Big Address Records (RFC 1639, FTP)
 
@@ -691,7 +721,7 @@ Floating Point Accelerator
 Field Programmable ALU Array (IC, ALU, RL)
 
 @item FPBGA
-Fine Pitch Ball Grid Array (CPU, IC)
+Fine Pitch Ball Grid Array (IC, CPU)
 
 @item FPC
 Floating Point Coprocessor
@@ -712,7 +742,7 @@ Field Programmable Gate Array (RL)
 Flux Changes per Inch (HDD)
 
 @item FPI
-Formal Public Identifier (DTD, SGML)
+Formal Public Identifier (DTD, SGML, SI)
 
 @item FPI
 Functional Process Improvement
@@ -840,6 +870,12 @@ File System Driver
 @item FSF
 Free Software Foundation (org., GNU)
 
+@item FSFE
+Free Software Foundation Europe (org., FSF)
+
+@item FSG
+Free Standards Group (org.)
+
 @item FSH
 File System Hierarchy (Linux, LSB)
 
@@ -891,6 +927,9 @@ Foiled Shielded Twisted Pair [cable] (STP, TP), "F/STP"
 @item FSU
 Free Software Union (org.)
 
+@item FSV
+Flexible Sender Validation (SPAM)
+
 @item FT1
 Fractional T1 (ISDN, T1, DS-0, DS-1)
 
@@ -909,6 +948,9 @@ Federal Trade Commission (org., USA)
 @item FTE
 [DCOM] For The Enterprise (DCOM, SAG)
 
+@item FTM
+File Transfer Manager (PDA, Casio)
+
 @item FTN
 Fido Technology Network (FidoNet)
 
@@ -960,6 +1002,9 @@ Freie Universitaet Berlin (org.)
 @item FUBAB
 Fouled / Fucked Up Beyond All Belief (slang, Usenet, IRC)
 
+@item FUBAR
+Failed UniBus Address Register (VAX)
+
 @item FUBAR
 Fouled / Fucked Up Beyond All Recognition / Repair (slang, Usenet, IRC)
 
@@ -975,6 +1020,9 @@ Frame User Network Interface
 @item FUEV
 Fernmeldeanlagen-UEberwachungsVerordnung
 
+@item FVD
+Forward Versatile Disc (China, WMV)
+
 @item FWH
 FirmWare Hub (BIOS, Intel)
 
@@ -984,6 +1032,12 @@ For What It's Worth (slang, Usenet, IRC)
 @item FWT
 Fast Wavelet Transformation
 
+@item FXO
+Foreign eXchange Office (FXS)
+
+@item FXS
+Foreign Exchange System / Subscriber (FXO)
+
 @item FXU
 FiXed point Unit (POWER, CPU)
 
