@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2003 Oliver Heidelbach
+@c Copyright (C) 1993/2005 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -10,7 +10,7 @@
 
 @table @asis
 @item MAC
-Mandatory Access Control (MLS)
+Mandatory Access Control (MLS, DAC)
 
 @item MAC
 Media Access Control (ISO, OSI, LAN, , WLAN, ...)
@@ -93,6 +93,9 @@ Maintenance Analysis Procedure (IBM)
 @item MAP
 Manufacturing Automation Protocol (General Motors)
 
+@item MAP
+Microsoft Academic Program (MS)
+
 @item MAP
 Mobile Application Part (MSC, GSM, mobile-systems)
 
@@ -117,6 +120,9 @@ Microprogram Address Register (IC)
 @item MARC
 MAchine Readable Cataloging [record]
 
+@item MARID
+MTA Authorization Records in DNS (MTA, DNS, SPAM, IETF, WG)
+
 @item MAS
 Multi Agent Systems (AI)
 
@@ -132,6 +138,9 @@ Message Administration Service Element
 @item MASM
 Microsoft ASseMbler (MS, assembler)
 
+@item MASS
+Message Authentication Signature Standards (MTA, SPAM, WG)
+
 @item MAU
 Medium Access Unit
 
@@ -180,6 +189,9 @@ Molecular Beam Epitaxy (IC; MOSFET)
 @item MBIT
 Mega Binary digIT (BIT), "MBit"
 
+@item MBOA
+MultiBand OFDM Alliance (org., OFDM)
+
 @item MBPS
 MegaBits Per Second (BIT)
 
@@ -189,6 +201,9 @@ Master Boot Record
 @item MBS
 Maximum Burst Size
 
+@item MBSA
+Microsoft Baseline Security Analyzer (MS, Windows)
+
 @item MBUS
 Module BUS [standard] (Sun, SPARC), "MBus"
 
@@ -237,9 +252,15 @@ Media Center Edition (MS, Windows, XP, OEM)
 @item MCEB
 Military Communications-Electronics Board (org., mil., USA)
 
+@item MCERT
+Mittelstand Computer Emergency Response Team Germany
+
 @item MCF
 Meta Content Framework / Format (Apple, WWW)
 
+@item MCF
+MOM Connector Framework (MS, MOM)
+
 @item MCGA
 Multi Color Graphics Adapter (IBM, PS/2)
 
@@ -282,6 +303,9 @@ Media and Communications Processor (IC)
 @item MCP
 Merlin Convenience Pack (IDB, OS/2)
 
+@item MCP
+Multiple-Chip Product (Intel)
+
 @item MCP
 Multiport / Multiprotocol Communication Processor
 
@@ -346,7 +370,7 @@ Master Control Unit (Nokia, OS)
 Micro Controller Unit (SIA, RL)
 
 @item MCU
-Multipoint Control Unit
+Multipoint Controller Unit (VoiP)
 
 @item MCVA
 Modified Constant Angular Velocity (Optical Disk)
@@ -471,6 +495,9 @@ Mapping Entity
 @item ME
 Millennium Edition (MS, Windows)
 
+@item MEBI
+MEgaBInary [(2^10)^2] (IEC)
+
 @item MEC
 Memory Expansion Card
 
@@ -528,12 +555,18 @@ MittelEuropaeische SommerZeit [+0200] (TZ)
 @item MET
 Memory Enhancement Technology (HP), "MEt"
 
+@item MET
+Micro Exposure Tool (Intel, EuropeV)
+
 @item MET
 Middle European Time [+0100] (TZ, CET, METDST, MEZ)
 
 @item METAL
 Machine Evaluation and Translation Language (Siemens)
 
+@item METAL
+Macro Expansion Template Attribute Language (TAL, ZPT, ZOPE)
+
 @item METDST
 Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 
@@ -609,6 +642,9 @@ Matrox Graphics Adapter (Matrox)
 @item MGA
 Monochrome Graphics Adapter
 
+@item MGCP
+Media Gateway Control Protocol (VoIP, RFC 2705)
+
 @item MGI
 Multi-Function Interpreter
 
@@ -901,7 +937,7 @@ MIDI Manufacturer Association (org., IMA)
 Mobile Media API (Java, Sun, JMF, API)
 
 @item MMC
-Microsoft Management Console (MS, Windows NT)
+Microsoft Management Console (MS, Windows NT, XP)
 
 @item MMC
 MIDI Machine Control
@@ -934,7 +970,7 @@ Make Money Fast (Usenet, ECP, EMP)
 Memory Mapped File (Windows 95, Windows NT)
 
 @item MMF
-Multimode Fiberoptic cable
+Multimode Fiberoptic cable (SMF)
 
 @item MMFS
 Manufacturing Message Format Standard (MAP)
@@ -957,6 +993,9 @@ Maker Markup Language (FrameMaker)
 @item MMOG
 Massive Multiplayer Online Games
 
+@item MMORPG
+Massive Multiplayer Online RolePlaying Games
+
 @item MMP
 Multilink Multichasis PPP (PPP)
 
@@ -996,6 +1035,9 @@ MultiMedia Video File [disk] (NEC, DVD)
 @item MMWM
 MultiMedia Window Manager (X-Windows)
 
+@item MMX
+Mobile Module PCI eXpress [specificiation] (Nvidia, PCIe)
+
 @item MMX
 MultiMedia eXtensions (Intel, CPU)
 
@@ -1008,6 +1050,9 @@ Metal Nitride Oxide Semiconductor (IC)
 @item MNP
 Microcom Networking Protocol
 
+@item MO
+Machine Object (PO)
+
 @item MO
 Management Object (OSI)
 
@@ -1041,6 +1086,9 @@ Managed Object Format (CIM, DMTF)
 @item MOF
 Meta Object Facility
 
+@item MOF
+Microsoft Operations Framework (MS)
+
 @item MOLAP
 Multidimensional OnLine Analytical Processing (OLAP)
 
@@ -1056,6 +1104,9 @@ Microsoft Open Licence Pack (MS)
 @item MOM
 Message Orientated Middleware (IBM)
 
+@item MOM
+Microsoft Operations Manager (MS, SMS)
+
 @item MONALISA
 MOdelling NAturaL Images for Synthesis and Animation, "MONA LISA"
 
@@ -1099,7 +1150,7 @@ Major Open Systems Environment Standards
 Metal Oxide Semiconductor Field Effect Transistor (IC, FET)
 
 @item MOSIX
-Multiprocessor ??? Operating System for unIX (Unix, Cluster)
+Multicomputer Operating System for UnIX (Unix, Cluster)
 
 @item MOSP
 Microsoft Online Services Partnership (MSN)
@@ -1143,6 +1194,9 @@ Magneto-Optical Write Once Read Many, "MO-WORM"
 @item MP
 [PPP] Multilink Protocol (MPPP, RFC 1990)
 
+@item MP
+Management Pack (MS, MOM)
+
 @item MP
 MegaPIXEL (PIXEL, photo)
 
@@ -1263,6 +1317,9 @@ Megabytes Per Second
 @item MPS
 MPOA Server (MPOA, ATM)
 
+@item MPS
+Multi Processor Specification (BIOS, HT, MS, Windows)
+
 @item MPS
 MultiPage Signal (Fax)
 
@@ -1272,6 +1329,9 @@ MultiProcessor Specification (SMP, Intel)
 @item MPSX
 Mathematical Programming System eXtended (IBM)
 
+@item MPT
+Memory Performance Technology (BIOS, MSI)
+
 @item MPT
 Ministery of Post and Telecommunications (org., Japan)
 
@@ -1377,6 +1437,9 @@ Macrocode Mask Read Only Memory (ROM)
 @item MROM
 Mask Read Only Memory (ROM)
 
+@item MROMB
+Modular RAID On MotherBoard (Intel, RAID, ZCR), "MRO MB"
+
 @item MRP
 Material / Manufacturing Resource Planning
 
@@ -1431,6 +1494,9 @@ Mini Slotted Alternating Priorities (MAC)
 @item MSB
 Most Significant Bit (BIT)
 
+@item MSBA
+Microsoft Baseline Security Analyzer (MS)
+
 @item MSC
 MicroSoft C
 
@@ -1467,12 +1533,12 @@ MicroSoft Download Library (MS)
 @item MSDN
 Macintosh Software Distribution Network (FidoNet, Apple)
 
-@item MSDN
-MicroSoft Developer Network (Internet, MS)
-
 @item MSDN
 MicroSoft Developer Network (MS)
 
+@item MSDNAA
+MicroSoft Developer Network Academic Alliance (MS)
+
 @item MSDOS
 MicroSoft Disk Operating System (MS, OS, PC)
 
@@ -1497,12 +1563,18 @@ MicroSoft Fax Information Service (MS)
 @item MSFP
 Management Service Focal Point (IBM)
 
+@item MSH
+Microsoft SHell (MS)
+
 @item MSI
 Medium Scale Integration
 
 @item MSI
 Micro-Star International (manufacturer, Taiwan)
 
+@item MSI
+MicroSoft Installer (MS, WIndows)
+
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW, MSIE)
 
@@ -1515,6 +1587,9 @@ Mobile Station ISDN Number (PLMN, GSM, mobile-systems), "MS-ISDN"
 @item MSIX
 Metered Services Information eXchange [protocol] (Internet, ISP)
 
+@item MSJVM
+MicroSoft Java Virtual Machine (MS, Java)
+
 @item MSL
 Maximum Segment Lifetime (TCP/IP)
 
@@ -1531,7 +1606,7 @@ Media Support Module (ODI)
 Metal Semiconductor Metal (IC)
 
 @item MSMQ
-MicroSoft Message Queue [server] (MS)
+MicroSoft Message Queue [server / services] (MS)
 
 @item MSN
 Microsoft Support Network (Internet, MS)
@@ -1677,6 +1752,12 @@ Magnetic Tunnel Junction (MRAM)
 @item MTOS
 Magnetic Tape Operating System (OS, Datapoint)
 
+@item MTP
+Media Transfer Protocol (Windows, MCE)
+
+@item MTP
+Memory Translation and Protection (Infiniband)
+
 @item MTP
 Message Transfer Part (ISDN, GSM, mobile-systems)
 
@@ -1791,6 +1872,9 @@ Multidomain Vertical Alignment [technology] (LCD, Fujitsu)
 @item MVC
 Model View Controller (Smalltalk, GUI)
 
+@item MVCC
+MultiVersion Concurrency Control [system] (PostgeSQL, DB)
+
 @item MVI
 Motion Video Instructions (DEC, CPU, Alpha)
 
