@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2003 Oliver Heidelbach
+@c Copyright (C) 1993/2005 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -18,6 +18,9 @@ Registration Authority (PKI, ITU, cryptography)
 @item RA
 Remote Access (BBS)
 
+@item RABF
+Redundant Accumulative Backhitchless Flush (IBM, Streamer)
+
 @item RAC
 Random Access Channel (HiperLAN/2)
 
@@ -30,6 +33,9 @@ Research and technology development in Advanced Communications technologies in E
 @item RACE
 Rowbased ASCII Compatible Encoding (ASCII, Internet, DOMAIN, VeriSign/NSI)
 
+@item RACER
+Renamed Abox and Concept Expression Reasoner
+
 @item RACF
 Resource Access Control Facility (IBM, MVS/ESA)
 
@@ -57,6 +63,9 @@ Remote Alarm Indication (DS3/E3)
 @item RAID
 Redundant Array of Independent / Inexpensive Disks (HDD, RAID)
 
+@item RAIDIOS
+RAID I/O Steering (Intel, RAID)
+
 @item RAIR
 Random Access Information Retrieval
 
@@ -81,6 +90,9 @@ Rapid Access Management Information System
 @item RAMP
 Remote Access Maintenance Protocol
 
+@item RAMPS
+Reliability, Availability, Manageability, Performance and Scalability (DB)
+
 @item RAMS
 Record Archival Management System
 
@@ -129,6 +141,9 @@ Relational Advanced Visual Environment
 @item RBA
 Relative Byte Address
 
+@item RBAC
+Role Based Access Control
+
 @item RBBS
 Remote Bulletin Board System (BBS)
 
@@ -216,6 +231,9 @@ Remote Carrier Module
 @item RCP
 Remote Copy Program
 
+@item RCP
+Rich Client Platform (Eclipse)
+
 @item RCS
 Reloadable Control Storage
 
@@ -234,6 +252,9 @@ Rewritable Consumer Time Code (video)
 @item RCTL
 Resistor-Capacitor-Transistor Logic
 
+@item RCW
+Runtime Callable Wrapper (.NET, COM, DLL)
+
 @item RD
 Receive Data (MODEM)
 
@@ -297,6 +318,9 @@ Record Definition Field
 @item RDF
 Resource Description Framework (XML, IBM, Netscape, MS, ..., WWW)
 
+@item RDFS
+Resource Description Framework Scheme (RDF)
+
 @item RDH
 RSA-DES-Hybridverschluesselung (cryptography, HBCI)
 
@@ -319,7 +343,7 @@ Relational Data Modeler
 Reliably Delivered Message
 
 @item RDMA
-Remote Direct Memory Access (VI)
+Remote Direct Memory Access (VI, Infiniband)
 
 @item RDN
 Relative Distinguished Name (X.500)
@@ -372,6 +396,9 @@ Radio Digital Terminal
 @item RDT
 Restricted Data Transmissions
 
+@item RE
+RAID Edition (WD, RAID)
+
 @item RE
 Recommendation Engine (OP, Oracle, DB)
 
@@ -408,6 +435,9 @@ Resources Management On-Line System
 @item RES
 Remote Entry Services
 
+@item REST
+REpresentational State Transfer (URL, AWS)
+
 @item RESTENA
 RESeau Teleinformatique de l'Education NAtionale et de la recherce (network, Luxembourg)
 
@@ -436,7 +466,7 @@ Remote FrameBuffer [protocol]
 Remote Function Call (SAP, CPIC)
 
 @item RFC
-Request For Change (PERL)
+Request For Change (PERL, ITIL)
 
 @item RFC
 Request For Comments (Internet, RFC)
@@ -507,6 +537,9 @@ Red Green Blue Alpha-[byte] (color system, RGB)
 @item RGBE
 Red Green Blue Emerald (color system, photo, Sony)
 
+@item RGMS
+Rotated Grid MultiSampling (graphics)
+
 @item RGP
 Raster Graphics Processor
 
@@ -516,6 +549,15 @@ Remote Graphics Processor
 @item RH
 Request Header
 
+@item RHCE
+Red Hat Certified Engineer (RedHat, Linux)
+
+@item RHCT
+Red Hat Certified Technician (RedHat, Linux)
+
+@item RHEL
+Red Hat Enterprise Linux (Linux, RedHat)
+
 @item RHS
 Right Hand Side (NGSCB, MS, Palladium)
 
@@ -567,9 +609,15 @@ Remote Installation and Maintenance
 @item RIME
 Relaynet International Message Exchange
 
+@item RIML
+Renderer Independent Markup Language (XML, Consensus)
+
 @item RIMM
 Rambus Inline Memory Module (Rambus, IC)
 
+@item RINEX
+Receiver INdependent EXchange [format] (GPS)
+
 @item RIO
 Redistributed Internet Objects (S3, VRML, Internet)
 
@@ -585,6 +633,9 @@ Raster Image Processor (DTP)
 @item RIP
 Remote Imaging Protocol (BBS)
 
+@item RIP
+Return Instruction Pointer (CPU, RAM)
+
 @item RIP
 Routing Information Protocol (BSD, IGP, RFC 1721, IP)
 
@@ -618,6 +669,9 @@ RISC Operating System (MIPS, Acorn, OS), "RISC OS"
 @item RISLU
 Remote Integrated Services Line Unit
 
+@item RISS
+[StorageWorks] Reference Information Storage System (HP)
+
 @item RITECH
 Resolution Improvement TECHnology (Epson)
 
@@ -657,6 +711,9 @@ Research Libraries Information Network (network)
 @item RLL
 Run Length Limited [encoding]
 
+@item RLM
+Redundant Lock Manager (GFS)
+
 @item RLN
 Remote LAN Nodes (LAN)
 
@@ -666,6 +723,9 @@ Radio Link Protocol (GSM, mobile-systems)
 @item RLP
 Resource Location Protocol (Internet, RFC 887)
 
+@item RLPR
+Remote Line Printing Request (LPR, printing)
+
 @item RLS
 Read Link error Status (FCP)
 
@@ -708,9 +768,15 @@ Resource Measurement Facility (IBM, MVS)
 @item RMI
 Remote Method Invocation (Java, API)
 
+@item RMIC
+??? (IBM, Streamer, WORM), "R-MIC"
+
 @item RMM
 Ring Management Module (Token Ring)
 
+@item RMODP
+Reference Model - Open Distributed Processing (RUP), "RM-ODP"
+
 @item RMON
 Remote MONitoring
 
@@ -742,7 +808,7 @@ REXXware Migration Tool (Simware, REXX)
 Ring ManagemenT (FDDI, SMT)
 
 @item RMX
-Reverse Mail eXchange (DNS)
+Reverse Mail eXchange (DNS, SPAM)
 
 @item RNA
 Remote Network Access
@@ -753,12 +819,18 @@ Radio Network Controller (mobile-systems, UMTS)
 @item RND
 RAD Network Devices (RAD, manufacturer)
 
+@item RNG
+Random Number Generation
+
 @item RNI
 Raw Native Interface (MS, Java)
 
 @item RNID
 Request Node IDentification (FCP, SNIA, HBA, API)
 
+@item RNM
+Resistors Network Method (audio)
+
 @item RNOC
 Regional Network Operations Center
 
@@ -799,7 +871,10 @@ Rewritable Optical Disk (OD)
 Roar Out From Laughing (slang, Usenet, IRC)
 
 @item ROHC
-RObust Header Compression (RFC 3095, RTP, UDP, ESP)
+RObust Header Compression (RFC 3095/3759, RTP, UDP, ESP)
+
+@item ROHS
+Restriction Of the use of certain Hazardous Substances in electrical and electronical equipment (Europe), "RoHS"
 
 @item ROLAP
 Relational OnLine Analytical Processing (OLAP, DB)
@@ -810,6 +885,9 @@ Routing Over Large Clouds
 @item ROM
 Read Only Memory (ROM)
 
+@item ROMB
+RAID On MotherBoard (RAID)
+
 @item ROMBIOS
 Read-Only Memory - Basic Input Output System (ROM, BIOS), "ROM-BIOS"
 
@@ -828,6 +906,9 @@ Resident Operating System (OS)
 @item ROSE
 Remote Operations Service Element (OSI, RPC)
 
+@item ROT
+Running Object Table (MS, Windows)
+
 @item ROTFL
 Rolling On The Floor Laughing (slang, Usenet, IRC)
 
@@ -858,6 +939,9 @@ Region code Playback Control phase 2 (DVD), "RPC-2"
 @item RPCL
 Remote Procedure Call Language (ONC, Sun)
 
+@item RPCS
+Ricoh Printer ???
+
 @item RPE
 Remote Peripheral Equipment
 
@@ -927,6 +1011,9 @@ Rock Ridge Interchange Protocol (CD, Unix)
 @item RRO
 Radial Run Out (DVD)
 
+@item RRP
+Registry Registrar Protocol (VeriSign, RFC 2832/3632)
+
 @item RRZE
 Regionales RechenZentrum Erlangen (org.)
 
@@ -1030,7 +1117,7 @@ Reality Signal Processor (Nintendo)
 Reed Solomon Product Code (SDD, CD), "RS-PC"
 
 @item RSS
-Rich Site Summary (XML)
+Rich / RDF Site Summary (XML, RDF)
 
 @item RSSCP
 Remote System Services Control Point (SSCP)
@@ -1048,7 +1135,7 @@ Remote Software Update (IBDM, OS/2, ...)
 Remote Switching Unit
 
 @item RSVP
-Resource reSerVation Protocol (IP)
+Resource reSerVation Protocol (IP, RFC 2205)
 
 @item RSX
 Realistic Sound eXperience (Intel, audio)
@@ -1158,6 +1245,9 @@ Real Time Language
 @item RTL
 Register Transfer Language (GCC)
 
+@item RTL
+Register Transfer Level
+
 @item RTL
 Resistor-Transistor Logic
 
@@ -1219,7 +1309,7 @@ Reliable Transfer Service Element (OSI)
 RealTime System Manager
 
 @item RTSP
-Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast)
+Real Time Streaming Protocol (TV, WWW, UDP, TCP/IP, RDP, Multicast, VoIP, RFC 2326)
 
 @item RTT
 Resonant Tunneling Transistor
@@ -1269,6 +1359,9 @@ Reality User Interface
 @item RUOW
 Remote Unit Of Work (DRDA, IBM), "RUoW"
 
+@item RUP
+Rational Unified Process (IBM)
+
 @item RUS
 Rechenzentrum der Universitaet Stuttgart (org., Uni Stuttgart, Germany)
 
@@ -1290,6 +1383,12 @@ ReWritable Product Promotion Initiative (org., DVD-R, DVD-RW, DVD)
 @item RWS
 Remote WinSock (Windows, TCP/IP)
 
+@item RWU
+Remote Wake-Up (LAN)
+
+@item RXR
+Regular XML RDF (XML, RDF)
+
 @item RZ
 RechenZentrum
 
